# Changelog

## 1.0.1 (2025-12-18)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/apologist-project/apg-sdk-python/compare/v1.0.0...v1.0.1)

### Bug Fixes

* use async_to_httpx_files in patch method ([c9e4b1b](https://github.com/apologist-project/apg-sdk-python/commit/c9e4b1bd6246d7dafd524d05895288e865fc958b))


### Chores

* **internal:** add missing files argument to base client ([4c11c62](https://github.com/apologist-project/apg-sdk-python/commit/4c11c62c01e8c8be109ea33bdf63a94cd385ec18))
* speedup initial import ([f0fa430](https://github.com/apologist-project/apg-sdk-python/commit/f0fa430ae3fb39f610bd013a819986eaa1113155))


### Refactors

* **internal:** switch from rye to uv ([ae2e974](https://github.com/apologist-project/apg-sdk-python/commit/ae2e97401c94bf5586f0873c6dc34822b1007b72))

## 1.0.0 (2025-12-10)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/apologist-project/apg-sdk-python/compare/v0.0.1...v1.0.0)

### Chores

* sync repo ([0c93074](https://github.com/apologist-project/apg-sdk-python/commit/0c930746b156721fbc30e55509b37458e176cbed))
* update SDK settings ([c0dc5fe](https://github.com/apologist-project/apg-sdk-python/commit/c0dc5fedacbef620debf66ff530b25bb57a93ad8))
* update SDK settings ([602e44d](https://github.com/apologist-project/apg-sdk-python/commit/602e44d8de902272aa820e6b9e53a62006912ba3))
